@@ -1,23 +1,10 @@
-/***************************************************************************
- *   Copyright (C) 2011 by Peter Penz <peter.penz19@gmail.com>             *
- *                                                                         *
- *   Based on the Itemviews NG project from Trolltech Labs                 *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2011 Peter Penz <peter.penz19@gmail.com>
+ *
+ * Based on the Itemviews NG project from Trolltech Labs
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "kitemmodelbase.h"
 
@@ -53,7 +40,7 @@ void KItemModelBase::setGroupedSorting(bool grouped)
     if (m_groupedSorting != grouped) {
         m_groupedSorting = grouped;
         onGroupedSortingChanged(grouped);
-        emit groupedSortingChanged(grouped);
+        Q_EMIT groupedSortingChanged(grouped);
     }
 }
 
@@ -68,7 +55,7 @@ void KItemModelBase::setSortRole(const QByteArray& role, bool resortItems)
         const QByteArray previous = m_sortRole;
         m_sortRole = role;
         onSortRoleChanged(role, previous, resortItems);
-        emit sortRoleChanged(role, previous);
+        Q_EMIT sortRoleChanged(role, previous);
     }
 }
 
@@ -83,7 +70,7 @@ void KItemModelBase::setSortOrder(Qt::SortOrder order)
         const Qt::SortOrder previous = m_sortOrder;
         m_sortOrder = order;
         onSortOrderChanged(order, previous);
-        emit sortOrderChanged(order, previous);
+        Q_EMIT sortOrderChanged(order, previous);
     }
 }
 
